@@ -31,7 +31,7 @@ use Sim::OPT::Parcoord3d;
 
 our @ISA = qw( Exporter );
 our @EXPORT = qw( interlinear, interstart prepfactlev tellstepsize );
-$VERSION = '0.169';
+$VERSION = '0.171';
 $ABSTRACT = 'Interlinear is a program for building metamodels from incomplete, multivariate, discrete dataseries on the basis of nearest-neighbouring gradients weighted by distance.';
 
 #######################################################################
@@ -1135,7 +1135,7 @@ sub wei
     my %nears = %{ $nears_ref };
     my @modality = @{ $modality_ref };
 
-    my @toinspects;
+    my ( @toinspects, @theseneighbours );
     if ( "wui" ~~ @modality )
     {
       foreach my $el ( keys %bank )
@@ -1147,8 +1147,14 @@ sub wei
           push ( @toinspects, @pair );
         }
       }
+      @toinspects = uniq( @toinspects ); #say "\@toinspects! " . dump( @toinspects );
+
+      foreach my $e ( @toinspects )
+      {
+        @theseneighbours = @{ isnear( $e, $first0, $last0 ) };
+      }
+      @theseneighbours = uniq( @theseneighbours ); say "\@theseneighbours! " . dump( @theseneighbours );
     }
-    @toinspects = uniq( @toinspects ); say "\@toinspects! " . dump( @toinspects );
 
     my %wand;
     my $coun = 0;
@@ -1156,7 +1162,7 @@ sub wei
     {
       my $key =  $el->[0] ;
 
-      if ( $el->[2] eq "" )
+      if ( ( $key ~~ @theseneighbours ) and ( $el->[2] eq "" ) )
       {
         my @neighbours;
         if ( not ( ( "wai" ~~ @modality ) or ( "wooi" ~~ @modality ) ) )
@@ -2248,7 +2254,7 @@ The parameter number is given by the position of the column (i.e. column 4 host
 Here below is an example of multivatiate dataseries of 3 parameters assuming 3 levels each. The numbers preceding the objective function (which is in the last colum) are the indices of the multidimensional matrix (tensor).
 
 
-1,1,1,1.234
+1,1,1,1,1.234
 
 1,2,3,2,1.500
 
@@ -2258,7 +2264,7 @@ Here below is an example of multivatiate dataseries of 3 parameters assuming 3 l
 
 2,2,3,2,0.000
 
-2,3,3,0.550
+2,3,3,1,0.550
 
 3,1,3,1
 
